# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/settings.py

from django.conf import settings

__all__ = [
    'CONTACT_EMAIL',
    'SHORT_NAME',
    'DESCRIPTION',
    'FAVICON_WIDTH',
    'FAVICON_HEIGHT',
    'FAVICON_TYPE',
    'FAVICON_FILE',
    'SEARCH_URL',
]


CONTACT_EMAIL = getattr(settings, 'OPENSEARCH_CONTACT_EMAIL', u'')
SHORT_NAME = getattr(settings, 'OPENSEARCH_SHORT_NAME', u'')
DESCRIPTION = getattr(settings, 'OPENSEARCH_DESCRIPTION', u'')
FAVICON_WIDTH = getattr(settings, 'OPENSEARCH_FAVICON_WIDTH', 16)
FAVICON_HEIGHT = getattr(settings, 'OPENSEARCH_FAVICON_HEIGHT', 16)
FAVICON_TYPE = getattr(settings, 'OPENSEARCH_FAVICON_TYPE', u'image/x-icon')
FAVICON_FILE = getattr(settings, 'OPENSEARCH_FAVICON_FILE', u'favicon.ico')
SEARCH_URL = getattr(settings, 'OPENSEARCH_SEARCH_URL', u'search')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# django-opensearch
# setup.py

from setuptools import setup, find_packages

# metadata
VERSION = (0, 1, 0)
__version__ = '.'.join(map(str, VERSION))

setup(
    name="django-opensearch",
    version=__version__,
    packages=find_packages(),
    install_requires=['Django', ],
    author="Alexei Andrushievich",
    author_email="vint21h@vint21h.pp.ua",
    description="Handle opensearch.xml",
    license="GPLv3 or later",
    url="https://github.com/vint21h/django-opensearch",
    download_url="https://github.com/vint21h/django-opensearch/archive/%s.tar.gz" % __version__,
    zip_safe=False,
    include_package_data=True,
    classifiers=[
        "Environment :: Plugins",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: Unix",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Topic :: Utilities",
    ]
)



# -*- coding: utf-8 -*-

# django-opensearch
# opensearch/urls.py

from django.conf.urls import patterns, url

# opesearch urls
urlpatterns = patterns('opensearch.views',
    url(r'^opensearch\.xml$', 'opensearch', name="opensearch"),  # opensearch
)
